"""
BRIAN support Endpoints
=========================

These endpoints are intended for use by BRIAN.

.. contents:: :local:

/poller/interfaces</hostname>
---------------------------------

.. autofunction:: inventory_provider.routes.poller.interfaces


/poller/speeds</hostname>
---------------------------------

.. autofunction:: inventory_provider.routes.poller.interface_speeds


/poller/eumetsat-multicast
---------------------------------

.. autofunction:: inventory_provider.routes.poller.eumetsat_multicast


/poller/gws/direct
---------------------------------

.. autofunction:: inventory_provider.routes.poller.gws_direct

"""
import json
import logging
import re

from flask import Blueprint, Response, current_app, request, jsonify
from lxml import etree

from inventory_provider import juniper
from inventory_provider.routes import common
from inventory_provider.routes.classifier import get_ims_equipment_name, \
    get_ims_interface
from inventory_provider.routes.common import _ignore_cache_or_retrieve

logger = logging.getLogger(__name__)
routes = Blueprint('poller-support-routes', __name__)

Gb = 1 << 30

INTERFACE_LIST_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',

    'definitions': {
        'service': {
            'type': 'object',
            'properties': {
                'id': {'type': 'integer'},
                'name': {'type': 'string'},
                'type': {'type': 'string'},
                'status': {'type': 'string'},
            },
            'required': ['id', 'name', 'type', 'status'],
            'additionalProperties': False
        },
        'interface': {
            'type': 'object',
            'properties': {
                'router': {'type': 'string'},
                'name': {'type': 'string'},
                'description': {'type': 'string'},
                'snmp-index': {
                    'type': 'integer',
                    'minimum': 1
                },
                'bundle': {
                    'type': 'array',
                    'items': {'type': 'string'}
                },
                'bundle-parents': {
                    'type': 'array',
                    'items': {'type': 'string'}
                },
                'circuits': {
                    'type': 'array',
                    'items': {'$ref': '#/definitions/service'}
                }
            },
            'required': [
                'router', 'name', 'description',
                'snmp-index', 'bundle', 'bundle-parents',
                'circuits'],
            'additionalProperties': False
        },
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/interface'}
}


INTERFACE_SPEED_LIST_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',

    'definitions': {
        'interface': {
            'type': 'object',
            'properties': {
                'router': {'type': 'string'},
                'name': {'type': 'string'},
                'speed': {'type': 'integer'}
            },
            'required': ['router', 'name', 'speed'],
            'additionalProperties': False
        },
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/interface'}
}

MULTICAST_SUBSCRIPTION_LIST_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',

    'definitions': {
        'ipv4-address': {
            'type': 'string',
            'pattern': r'^(\d+\.){3}\d+$'
        },
        'subscription': {
            'type': 'object',
            'properties': {
                'router': {'type': 'string'},
                'subscription': {'$ref': '#/definitions/ipv4-address'},
                'endpoint': {'$ref': '#/definitions/ipv4-address'},
                'oid': {
                    'type': 'string',
                    'pattern': r'^(\d+\.)*\d+$'
                },
                'community': {'type': 'string'}
            },
            'required': [
                'router', 'subscription', 'endpoint', 'oid', 'community'],
            'additionalProperties': False
        },
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/subscription'}
}

GWS_DIRECT_DATA_SCHEMA = {
    '$schema': 'http://json-schema.org/draft-07/schema#',

    'definitions': {
        'snmp-counter': {
            'type': 'object',
            'properties': {
                'hostname': {'type': 'string'},
                'community': {'type': 'string'},
                'oid': {
                    'type': 'string',
                    'pattern': r'^(\d+\.)*\d+$'
                }
            },
            'required': ['hostname', 'community', 'oid'],
            'additionalProperties': False
        },
        'snmp-counter-list': {
            'type': 'array',
            'items': {'$ref': '#/definitions/snmp-counter'},
            'minItems': 1
        },
        'isp-counters': {
            'type': 'object',
            'properties': {
                'traffic_in': {'$ref': '#/definitions/snmp-counter-list'},
                'traffic_out': {'$ref': '#/definitions/snmp-counter-list'},
                'discards_in': {'$ref': '#/definitions/snmp-counter-list'},
                'discards_out': {'$ref': '#/definitions/snmp-counter-list'},
                'errors_in': {'$ref': '#/definitions/snmp-counter-list'},
                'errors_out': {'$ref': '#/definitions/snmp-counter-list'}
            },
            'required': ['traffic_in', 'traffic_out'],
            'additionalProperties': False
        },
        'nren-isp-direct-counters': {
            'type': 'object',
            'properties': {
                'nren': {'type': 'string'},
                'isp': {
                    'type': 'string',
                    'enum': ['Cogent', 'Telia', 'Century Link']
                },
                'counters': {'$ref': '#/definitions/isp-counters'},
            },
            'required': ['nren', 'isp', 'counters'],
            'additionalProperties': False
        }
    },

    'type': 'array',
    'items': {'$ref': '#/definitions/nren-isp-direct-counters'}
}


@routes.after_request
def after_request(resp):
    return common.after_request(resp)


def _load_interface_bundles(hostname=None):
    result = dict()

    def _load_docs(key_pattern):
        for doc in common.load_json_docs(
                config_params=current_app.config['INVENTORY_PROVIDER_CONFIG'],
                key_pattern=key_pattern,
                num_threads=20):

            m = re.match(
                r'.*netconf-interface-bundles:([^:]+):(.+)', doc['key'])
            assert m

            router = m.group(1)
            interface = m.group(2)
            result.setdefault(router, dict())
            result[router][interface] = doc['value']

    base_key = 'netconf-interface-bundles'
    base_key_pattern = f'{base_key}:{hostname}:*' \
        if hostname else f'{base_key}:*'

    _load_docs(base_key_pattern)
    _load_docs(f'lab:{base_key_pattern}')

    return result


def _load_services(hostname=None):
    # if hostname:
    #     hostname = get_ims_equipment_name(hostname)

    result = dict()
    key_pattern = f'ims:interface_services:{hostname}:*' \
        if hostname else 'ims:interface_services:*'

    def _filter_and_format_services(_services):
        included_service_ids = set()
        for s in _services:
            if s['id'] in included_service_ids:
                continue
            if s['circuit_type'] == 'service':
                included_service_ids.add(s['id'])
                yield {
                    'id': s['id'],
                    'name': s['name'],
                    'type': s['service_type'],
                    'status': s['status']
                }

    for doc in common.load_json_docs(
            config_params=current_app.config['INVENTORY_PROVIDER_CONFIG'],
            key_pattern=key_pattern,
            num_threads=20):

        m = re.match(r'^ims:interface_services:([^:]+):(.+)', doc['key'])
        if not m:
            logger.warning(f'can\'t parse redis service key {doc["key"]}')
            # there are some weird records (dtn*, dp1*)
            continue

        router = m.group(1)
        interface = m.group(2)
        result.setdefault(router, dict())
        result[router][interface] = \
            list(_filter_and_format_services(doc['value']))

    return result


def _load_interfaces(hostname):
    """
    loads basic interface data for production & lab routers

    :param hostname:
    :return:
    """
    def _load_docs(key_pattern):

        m = re.match(r'^(.*netconf:).+', key_pattern)
        assert m  # sanity
        key_prefix_len = len(m.group(1))
        assert key_prefix_len >= len('netconf:')  # sanity

        for doc in common.load_xml_docs(
                config_params=current_app.config['INVENTORY_PROVIDER_CONFIG'],
                key_pattern=key_pattern,
                num_threads=10):

            router = doc['key'][key_prefix_len:]

            for ifc in juniper.list_interfaces(doc['value']):
                if not ifc['description']:
                    continue

                yield {
                    'router': router,
                    'name': ifc['name'],
                    'bundle': ifc['bundle'],
                    'bundle-parents': [],
                    'description': ifc['description'],
                    'circuits': []
                }

    base_key_pattern = f'netconf:{hostname}*' if hostname else 'netconf:*'
    yield from _load_docs(base_key_pattern)
    yield from _load_docs(f'lab:{base_key_pattern}')


def _add_bundle_parents(interfaces, hostname=None):
    """
    generator that adds bundle-parents info to each interface.

    :param interfaces: result of _load_interfaces
    :param hostname: hostname or None for all
    :return: generator with bundle-parents populated in each element
    """
    bundles = _load_interface_bundles(hostname)

    for ifc in interfaces:
        router_bundle = bundles.get(ifc['router'], None)
        if router_bundle:
            base_ifc = ifc['name'].split('.')[0]
            ifc['bundle-parents'] = router_bundle.get(base_ifc, [])
        yield ifc


def _add_circuits(interfaces, hostname=None):
    """
    generator that adds service info to each interface.

    :param interfaces: result of _load_interfaces
    :param hostname: hostname or None for all
    :return: generator with 'circuits' populated in each element, if present
    """

    if hostname:
        hostname = get_ims_equipment_name(hostname)
    services = _load_services(hostname)
    for ifc in interfaces:
        router_services = services.get(
            get_ims_equipment_name(ifc['router']), None)
        if router_services:
            ifc['circuits'] = router_services.get(
                get_ims_interface(ifc['name']), []
            )

        yield ifc


def _add_snmp_indexes(interfaces, hostname=None):
    """
    generator that adds snmp info to each interface, if available

    :param interfaces: result of _load_interfaces
    :param hostname: hostname or None for all
    :return: generator with 'snmp-index' optionally added to each element
    """
    snmp_indexes = common.load_snmp_indexes(hostname)
    for ifc in interfaces:
        router_snmp = snmp_indexes.get(ifc['router'], None)
        if router_snmp and ifc['name'] in router_snmp:
            ifc['snmp-index'] = router_snmp[ifc['name']]['index']
            # TODO: uncomment this when it won't break poller-admin-service
            # not urgent ... it looks empirically like all logical-system
            #                interfaces are repeated for both communities
            # ifc['snmp-community'] = router_snmp[ifc['name']]['community']
        yield ifc


def _load_interfaces_to_poll(hostname=None):
    """
    prepares the result of a call to /interfaces

    :param hostname: hostname or None for all
    :return: generator yielding interface elements
    """
    basic_interfaces = _load_interfaces(hostname)
    with_bundles = _add_bundle_parents(basic_interfaces, hostname)
    with_circuits = _add_circuits(with_bundles, hostname)
    with_snmp = _add_snmp_indexes(with_circuits, hostname)

    def _has_snmp_index(ifc):
        return 'snmp-index' in ifc

    # only return interfaces that can be polled
    return filter(_has_snmp_index, with_snmp)


@routes.route("/interfaces", methods=['GET', 'POST'])
@routes.route('/interfaces/<hostname>', methods=['GET', 'POST'])
@common.require_accepts_json
def interfaces(hostname=None):
    """
    Handler for `/poller/interfaces` and
    `/poller/interfaces/<hostname>`
    which returns information for either all interfaces
    or those on the requested hostname.

    The response is a list of information for all
    interfaces that should be polled, including service
    information and snmp information.

    .. asjson::
       inventory_provider.routes.poller.INTERFACE_LIST_SCHEMA

    :param hostname: optional, if present should be a router hostname
    :return:
    """

    cache_key = f'classifier-cache:poller-interfaces:{hostname}' \
        if hostname else 'classifier-cache:poller-interfaces:all'

    r = common.get_current_redis()

    result = _ignore_cache_or_retrieve(request, cache_key, r)

    if not result:
        result = list(_load_interfaces_to_poll(hostname))
        if not result:
            return Response(
                response='no interfaces found',
                status=404,
                mimetype='text/html')

        result = json.dumps(result)
        # cache this data for the next call
        r.set(cache_key, result.encode('utf-8'))

    return Response(result, mimetype="application/json")


def interface_speed(ifc):
    """
    Return the maximum bits per second expected for the given interface.

    cf. https://www.juniper.net/documentation/us/en/software/
               vmx/vmx-getting-started/topics/task/
               vmx-chassis-interface-type-configuring.html

    :param ifc:
    :return: an integer bits per second
    """

    def _name_to_speed(ifc_name):
        if ifc_name.startswith('ge'):
            return Gb
        if ifc_name.startswith('xe'):
            return 10 * Gb
        if ifc_name.startswith('et'):
            return 100 * Gb
        logger.warning(f'unrecognized interface name: {ifc_name}')
        return -1

    if ifc['bundle-parents']:
        if not ifc['name'].startswith('ae'):
            logger.warning(
                f'ifc has bundle-parents, but name is {ifc["name"]}')
        return sum(_name_to_speed(name) for name in ifc['bundle-parents'])

    return _name_to_speed(ifc['name'])


def _load_interfaces_and_speeds(hostname=None):
    """
    prepares the result of a call to /speeds

    :param hostname: hostname or None for all
    :return: generator yielding interface elements
    """
    basic_interfaces = _load_interfaces(hostname)
    with_bundles = _add_bundle_parents(basic_interfaces, hostname)

    def _result_ifc(ifc):
        return {
            'router': ifc['router'],
            'name': ifc['name'],
            'speed': interface_speed(ifc)
        }

    return map(_result_ifc, with_bundles)


@routes.route("/speeds", methods=['GET', 'POST'])
@routes.route('/speeds/<hostname>', methods=['GET', 'POST'])
@common.require_accepts_json
def interface_speeds(hostname=None):
    """
    Handler for `/poller/speeds` and
    `/poller/speeds/<hostname>`
    which returns information for either all interfaces
    or those on the requested hostname.

    The response is a list of maximum speed information (in bits
    per second) for all known interfaces.

    *speed <= 0 means the max interface speed can't be determined*

    .. asjson::
       inventory_provider.routes.poller.INTERFACE_SPEED_LIST_SCHEMA

    :param hostname: optional, if present should be a router hostname
    :return:
    """

    cache_key = f'classifier-cache:poller-interface-speeds:{hostname}' \
        if hostname else 'classifier-cache:poller-interface-speeds:all'

    r = common.get_current_redis()

    result = _ignore_cache_or_retrieve(request, cache_key, r)

    if not result:
        result = list(_load_interfaces_and_speeds(hostname))
        if not result:
            return Response(
                response='no interfaces found',
                status=404,
                mimetype='text/html')

        result = json.dumps(result)
        # cache this data for the next call
        r.set(cache_key, result.encode('utf-8'))

    return Response(result, mimetype="application/json")


@routes.route("/eumetsat-multicast", methods=['GET', 'POST'])
@common.require_accepts_json
def eumetsat_multicast(hostname=None):
    """
    Handler for `/poller/eumetsat-multicast` which returns information about
    multicast subscriptions on mx1.fra.de.geant.net.

    The response is a list of oid/router/community structures that all
    all subscription octet counters to be polled.

    .. asjson::
       inventory_provider.routes.poller.MULTICAST_SUBSCRIPTION_LIST_SCHEMA

    This method returns essentially hard-coded data,
    based on the information in POL1-395.

    :return:
    """

    MX1_FRA = 'mx1.fra.de.geant.net'
    SUBSCRIPTIONS = [{
            'subscription': f'232.223.222.{idx}',
            'endpoint': '193.17.9.3',
        } for idx in range(1, 73)]

    SUBSCRIPTIONS.append(
        {'subscription': '232.223.223.1',  'endpoint': '193.17.9.7'})
    SUBSCRIPTIONS.append(
        {'subscription': '232.223.223.22',  'endpoint': '193.17.9.7'})

    def _oid(sub):
        return ('1.3.6.1.2.1.83.1.1.2.1.16'
                f'.{sub["subscription"]}.{sub["endpoint"]}'
                '.255.255.255.255')

    cache_key = 'classifier-cache:poller-eumetsat-multicast'

    r = common.get_current_redis()

    result = r.get(cache_key)
    if result:
        result = result.decode('utf-8')
    else:
        netconf = r.get(f'netconf:{MX1_FRA}')
        if not netconf:
            return Response(
                status=503,
                response=f'error loading netconf for {MX1_FRA}')

        netconf_doc = etree.fromstring(netconf.decode('utf-8'))
        community = juniper.snmp_community_string(netconf_doc)
        if not community:
            return Response(
                status=503,
                response=f'error extracting community string for {MX1_FRA}')

        def _rsp_element(sub):
            result = {
                'router': MX1_FRA,
                'oid': _oid(sub),
                'community': community
            }
            result.update(sub)
            return result

        result = [_rsp_element(sub) for sub in SUBSCRIPTIONS]

        result = json.dumps(result)
        # cache this data for the next call
        r.set(cache_key, result.encode('utf-8'))

    return Response(result, mimetype="application/json")


@routes.route("/gws/direct", methods=['GET', 'POST'])
@common.require_accepts_json
def gws_direct():
    """
    Handler for `/poller/gws/direct` which returns required for polling
     customer equipment counters for ISP connetions.

    The response is a list of nren/isp/counter structures that must be
    polled.

    .. asjson::
       inventory_provider.routes.poller.GWS_DIRECT_DATA_SCHEMA

    This method returns essentially hard-coded data,
    based on the information in POL1-422.

    TODO: this hard-coded data should be in the config file

    :return:
    """
    data = [
      {
        "nren": "ARNES",
        "isp": "Cogent",
        "counters": {
          "discards_in": [
            {
              "hostname": "88.200.0.63",
              "community": "gn2nocT3st",
              "oid": "1.3.6.1.2.1.2.2.1.13.533"
            }
          ],
          "discards_out": [
            {
              "hostname": "88.200.0.63",
              "community": "gn2nocT3st",
              "oid": "1.3.6.1.2.1.2.2.1.19.533"
            }
          ],
          "errors_in": [
            {
              "hostname": "88.200.0.63",
              "community": "gn2nocT3st",
              "oid": "1.3.6.1.2.1.2.2.1.14.533"
            }
          ],
          "errors_out": [
            {
              "hostname": "88.200.0.63",
              "community": "gn2nocT3st",
              "oid": "1.3.6.1.2.1.2.2.1.20.533"
            }
          ],
          "traffic_in": [
            {
              "hostname": "88.200.0.63",
              "community": "gn2nocT3st",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.531"
            },
            {
              "hostname": "88.200.0.63",
              "community": "gn2nocT3st",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.525"
            },
            {
              "hostname": "88.200.0.63",
              "community": "gn2nocT3st",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.553"
            },
            {
              "hostname": "88.200.0.63",
              "community": "gn2nocT3st",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.563"
            }
          ],
          "traffic_out": [
            {
              "hostname": "88.200.0.63",
              "community": "gn2nocT3st",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.531"
            },
            {
              "hostname": "88.200.0.63",
              "community": "gn2nocT3st",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.525"
            },
            {
              "hostname": "88.200.0.63",
              "community": "gn2nocT3st",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.553"
            },
            {
              "hostname": "88.200.0.63",
              "community": "gn2nocT3st",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.563"
            }
          ]
        }
      },
      {
        "nren": "ARNES",
        "isp": "Telia",
        "counters": {
          "traffic_in": [
            {
              "hostname": "62.40.124.6",
              "community": "gn2nocT3st",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.611"
            },
            {
              "hostname": "62.40.124.6",
              "community": "gn2nocT3st",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.589"
            }
          ],
          "traffic_out": [
            {
              "hostname": "62.40.124.6",
              "community": "gn2nocT3st",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.611"
            },
            {
              "hostname": "62.40.124.6",
              "community": "gn2nocT3st",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.589"
            }
          ]
        }
      },
      {
        "nren": "CARNET",
        "isp": "Cogent",
        "counters": {
          "traffic_in": [
            {
              "hostname": "62.40.124.10",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.35"
            }
          ],
          "traffic_out": [
            {
              "hostname": "62.40.124.10",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.35"
            }
          ]
        }
      },
      {
        "nren": "CARNET",
        "isp": "Telia",
        "counters": {
          "traffic_in": [
            {
              "hostname": "62.40.125.150",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.48"
            }
          ],
          "traffic_out": [
            {
              "hostname": "62.40.125.150",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.48"
            }
          ]
        }
      },
      {
        "nren": "KIFU",
        "isp": "Cogent",
        "counters": {
          "traffic_in": [
            {
              "hostname": "195.111.97.108",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.155"
            }
          ],
          "traffic_out": [
            {
              "hostname": "195.111.97.108",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.155"
            }
          ]
        }
      },
      {
        "nren": "KIFU",
        "isp": "Telia",
        "counters": {
          "traffic_in": [
            {
              "hostname": "195.111.97.108",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.148"
            }
          ],
          "traffic_out": [
            {
              "hostname": "195.111.97.108",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.148"
            }
          ]
        }
      },
      {
        "nren": "RedIRIS",
        "isp": "Telia",
        "counters": {
          "traffic_in": [
            {
              "hostname": "130.206.206.250",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.1487"
            },
            {
              "hostname": "130.206.206.250",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.1488"
            },
            {
              "hostname": "130.206.206.250",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.1489"
            },
            {
              "hostname": "130.206.206.250",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.760"
            },
            {
              "hostname": "130.206.206.250",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.796"
            }
          ],
          "traffic_out": [
            {
              "hostname": "130.206.206.250",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.1487"
            },
            {
              "hostname": "130.206.206.250",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.1488"
            },
            {
              "hostname": "130.206.206.250",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.1489"
            },
            {
              "hostname": "130.206.206.250",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.760"
            },
            {
              "hostname": "130.206.206.250",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.796"
            }
          ]
        }
      },
      {
        "nren": "RoEduNet",
        "isp": "Cogent",
        "counters": {
          "traffic_in": [
            {
              "hostname": "149.6.50.10",
              "community": "dante",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.531"
            }
          ],
          "traffic_out": [
            {
              "hostname": "149.6.50.10",
              "community": "dante",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.531"
            }
          ]
        }
      },
      {
        "nren": "RoEduNet",
        "isp": "Century Link",
        "counters": {
          "traffic_in": [
            {
              "hostname": "212.162.45.194",
              "community": "dante",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.9"
            }
          ],
          "traffic_out": [
            {
              "hostname": "212.162.45.194",
              "community": "dante",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.9"
            }
          ]
        }
      },
      {
        "nren": "EENet",
        "isp": "Telia",
        "counters": {
          "traffic_in": [
            {
              "hostname": "193.40.133.2",
              "community": "geant-mon-telia",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.263"
            }
          ],
          "traffic_out": [
            {
              "hostname": "193.40.133.2",
              "community": "geant-mon-telia",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.263"
            }
          ]
        }
      },
      {
        "nren": "PSNC",
        "isp": "Century Link",
        "counters": {
          "traffic_in": [
            {
              "hostname": "212.191.126.6",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.675"
            },
            {
              "hostname": "212.191.126.7",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.6.677"
            }
          ],
          "traffic_out": [
            {
              "hostname": "212.191.126.6",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.675"
            },
            {
              "hostname": "212.191.126.7",
              "community": "atlas1453",
              "oid": "1.3.6.1.2.1.31.1.1.1.10.677"
            }
          ]
        }
      }
    ]

    return jsonify(data)
